# Produce Figure 1, Figure 2, Figure 3, Table 2, Table 3 for Accountability paper
# Author: Pavel Atanasov

library(ggplot2)
setwd("/Users/pavel/Dropbox/Accountability Paper/20170630_ALTV_datasets")
#setwd("~/ACE/data")
source("../scoring/score_methods.R")
source("../util/load_data.R")
UnCache(all=TRUE)

# Import data
ifps_yr4 <- read.csv("/Users/pavel/Dropbox/Accountability Paper/Drafts/20170630_ALTV_datasets/ifps.csv", stringsAsFactors=F)
surv_scores_bs <- fread("/Users/pavel/Dropbox/Accountability Paper/Drafts/20170630_ALTV_datasets/brier_indiv.csv", stringsAsFactors=FALSE)
surv_scores_abs <- fread("/Users/pavel/Dropbox/Accountability Paper/Drafts/20170630_ALTV_datasets/abs_indiv.csv", stringsAsFactors=FALSE)

surv_scores_abs$abs_score <- surv_scores_abs$score

surv_scores <- merge(surv_scores_bs, 
                    subset(surv_scores_abs, select=c("ifp_id","user_id","abs_score")),
                    by=c("user_id","ifp_id"), all.x=T)

surv_scores <- data.table(surv_scores)
surv_scores$ct <- substr(surv_scores$ctt,1,2)
surv_scores$team <- substr(surv_scores$ctt,1,1)
surv_scores$accountability <- substr(surv_scores$ctt,2,2)
table(surv_scores$ct)
surv_scores <- surv_scores[,n:=length(score), by="user_id"]
surv_scores <- subset(surv_scores,  imputed==0 & !(ct %in% c("1a", "5s"))) # All forecasters
# Note the error
surv_scores <- surv_scores[, scaled_score:=scale(score), by="ifp_id"]
surv_scores <- surv_scores[, scaled_asb_score:=scale(abs_score), by="ifp_id"]

surv_scores_ifps <- merge(surv_scores, 
                      subset(ifps_yr4, select=c("ifp_id", "date_start", "date_closed")), 
                      by="ifp_id")

# If a question was a carry over, it started again on day 1 of season 4
surv_scores_ifps$date_start[as.Date(surv_scores_ifps$date_start)<kYear4Start] <- as.character(kYear4Start)
# Measure the mid-point of each question, where did it fall from 0% (start of season) to 100% (end of season)
surv_scores_ifps$date_percent_midpoint <- as.numeric( difftime(as.Date(surv_scores_ifps$date_start), as.Date(kYear4Start), units = "days") + 
                                                  difftime(as.Date(surv_scores_ifps$date_closed), as.Date(kYear4Start), units = "days")) / (292*2)

# Add grouping, based on Jon's code
surv_scores_ifps$Group <- ifelse(substr(surv_scores_ifps$ctt,1,1)=="4",surv_scores_ifps$ctt,surv_scores_ifps$user_id)

# Brier score
# No interaction
summary(lmer(score ~ team + accountability + (1|ifp_id), data=surv_scores_ifps))
summary(lmer(score ~ team + accountability + (1|ifp_id) + (1|Group), data=surv_scores_ifps))
# Across question time
summary(lmer(score ~ team + accountability*date_percent_midpoint + 
                  (1|ifp_id), 
             data=surv_scores_ifps))
# Add group, More conservative model, use that one
summary(lmer(score ~ team + accountability*date_percent_midpoint + 
                  (1|ifp_id) + (1|Group), 
             data=surv_scores_ifps))


# Absolute distance
# No Interaction
summary(lmer(abs_score ~ team + accountability + (1|ifp_id), data=surv_scores_ifps))
summary(lmer(abs_score ~ team + accountability + (1|ifp_id)  + (1|Group), data=surv_scores_ifps))
# Across question time
summary(lmer(abs_score ~ team + accountability*date_percent_midpoint + 
                  (1|ifp_id) , data=surv_scores_ifps))
# Add group, more conservative model, use that one
summary(lmer(abs_score ~ team + accountability*date_percent_midpoint + 
                  (1|ifp_id) + (1|Group), data=surv_scores_ifps))


