source("~/ACE/util/load_data.R", chdir = TRUE)
library(Hmisc)
setwd("/Users/pavel/Dropbox/Accountability Paper/20170630_ALTV_datasets")

# This file already has yr3 membership and indiv diff / demographic data merged in 
users.yr4 <- fread("../20170630_ALTV_datasets/demographics.csv")


# report, by ct, age, gender, percent with post-BA education


setkey(users.yr4, ct)
ct.summary <- users.yr4[ , list(n_start = .N, 
                                per_male = sum(gender, na.rm = TRUE) / sum(gender %in% c(0,1), na.rm = TRUE),
                                mean_age = mean(age, na.rm = TRUE),
                                sd_age = sd(age, na.rm = TRUE),
                                per_college = mean(education >= 4, na.rm = TRUE),
                                per_citizen = sum(citizen, na.rm = TRUE) / sum(citizen %in% c(0,1), na.rm = TRUE)), "ct"]

setkey(ct.summary, ct)
ct.summary
users.yr4[ , length(unique(ctt)), "ct"]


# count disabled users
users.yr4[ status == 0, .N, "ct"]
length(users.yr4[ status == 0, user_id])

disabled.users <- users.yr4[ status == 0, ]
ct.disabled <- disabled.users[ , list(n_quit = .N), "ct"]
train.disabled <- disabled.users[ , list(n_quit = .N), "training"]
setkey(ct.disabled, ct)

ct.summary <- merge(ct.summary, ct.disabled, by = "ct", all = TRUE)
ct.summary[ , per_dropout := round(n_quit / n_start, 2), ]
setcolorder(ct.summary, c("ct", "n_start", "n_quit", "per_dropout", "per_male",
                          "mean_age", "sd_age", "per_college", "per_citizen"))

# 
# 2. Statistical tests for the variables below, collapse between teams/indivs, 
# just three way F-tests or chi-squared tests. 
# Dropout rate (%)
# Male (%)
# Age
# mean (sd)
# BA
# Citizen
users.yr4
names(ct.summary)
names(users.yr4)
ct.summary[ , n_remain := n_start - n_quit,  ]
ct.summary[ , male := n_start * per_male,  ]
ct.summary[ , female := n_start * (1-per_male),  ]

ct.summary[ , num_college := n_start * per_college,  ]
ct.summary[ , num_no_college := n_start * (1-per_college),  ]

ct.summary[ , num_citizen := n_start * per_citizen,  ]
ct.summary[ , num_no_citizen := n_start * (1-per_citizen),  ]
library(stats)
chisq.test(cbind(ct.summary$male, ct.summary$female) )
chisq.test(cbind(ct.summary$num_college, ct.summary$num_no_college) )
chisq.test(cbind(ct.summary$num_citizen, ct.summary$num_no_citizen) )
chisq.test(cbind(ct.summary$n_remain, ct.summary$n_quit) )

summary(aov(data = users.yr4, age ~ ct ))

train.summary <- users.yr4[ , list(n_start = .N, 
                                per_male = sum(gender, na.rm = TRUE) / sum(gender %in% c(0,1), na.rm = TRUE),
                                mean_age = mean(age, na.rm = TRUE),
                                sd_age = sd(age, na.rm = TRUE),
                                per_college = mean(education >= 4, na.rm = TRUE),
                                per_citizen = sum(citizen, na.rm = TRUE) / sum(citizen %in% c(0,1), na.rm = TRUE),
                                median_news_hrs = median(newshrs_num, na.rm = TRUE)), "training"]


train.summary <- merge(train.summary, train.disabled, by = "training", all = TRUE)



train.summary[ , n_remain := n_start - n_quit,  ]
train.summary[ , male := n_start * per_male,  ]
train.summary[ , female := n_start * (1-per_male),  ]

train.summary[ , num_college := n_start * per_college,  ]
train.summary[ , num_no_college := n_start * (1-per_college),  ]

train.summary[ , num_citizen := n_start * per_citizen,  ]
train.summary[ , num_no_citizen := n_start * (1-per_citizen),  ]
library(stats)
chisq.test(cbind(train.summary$male, train.summary$female) )
chisq.test(cbind(train.summary$num_college, train.summary$num_no_college) )
chisq.test(cbind(train.summary$num_citizen, train.summary$num_no_citizen) )
chisq.test(cbind(train.summary$n_remain, train.summary$n_quit) )

summary(aov(data = users.yr4, age ~ training ))
# Number of forecasts
# Number of key comments
# Number of key comment ratings 